PacketHeader

Struct PacketHeader 

pub struct PacketHeader {
    pub packet_type: PacketType,
    pub status: PacketStatus,
    pub length: u16,
    pub spid: u16,
    pub packet_id: u8,
    pub window: u8,
}
TDS packet header.

Every TDS packet begins with an 8-byte header that describes the packet type, status, and length.

Fields

packet_type: PacketType

Type of packet.

status: PacketStatus

Status flags.

length: u16

Total packet length including header.

spid: u16

Server process ID (SPID).

packet_id: u8

Packet sequence number (wraps at 255).

window: u8

Window (unused, should be 0).

Implementations

Source

impl PacketHeader

pub const fn new( packet_type: PacketType, status: PacketStatus, length: u16, ) -> Self

Create a new packet header.

pub fn decode(src: &mut impl Buf) -> Result<Self, ProtocolError>

Parse a packet header from bytes.

pub fn encode(&self, dst: &mut impl BufMut)

Encode the packet header to bytes.

pub fn encode_to_bytes(&self) -> Bytes

Encode the packet header to a new Bytes buffer.

pub const fn payload_length(&self) -> usize

Get the payload length (total length minus header).

pub const fn is_end_of_message(&self) -> bool

Check if this is the last packet in a message.

pub const fn with_packet_id(self, id: u8) -> Self

Set the packet ID (sequence number).

pub const fn with_spid(self, spid: u16) -> Self

Set the SPID.